server_client_20141231_085104

### config2 : test_negative_correctness

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 3.07363605499 sec | 9.59445810318 sec

Error message: Did not receive 0 in client1

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 49.58 | 13.38 | 0.67 | 1.64 | 14.15 | 35.41 | 42.49 | 48.16 | 20.91
qps | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 0.0

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 395.75 | 395.75 | 395.75 | 395.75 | 395.75 | 395.75 | 395.75 | 395.75 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | 4.0
server1-perf | latency | p50 lt 0.3 | 1.644
server1-perf | latency | mean lt 0.33 | 13.38275
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | 1.0
client1-perf | latency | p50 lt 22.0 | 395.745
client1-perf | latency | mean lt 35.0 | 395.745
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None